@@ -24,21 +24,21 @@ namespace ICalDrag
 /**
   Mime-type of iCalendar
 */
-Q_REQUIRED_RESULT KCALUTILS_EXPORT QString mimeType();
+[[nodiscard]] KCALUTILS_EXPORT QString mimeType();
 
 /**
   Sets the iCalendar representation as data of the drag object
 */
-Q_REQUIRED_RESULT KCALUTILS_EXPORT bool populateMimeData(QMimeData *e, const KCalendarCore::Calendar::Ptr &cal);
+[[nodiscard]] KCALUTILS_EXPORT bool populateMimeData(QMimeData *e, const KCalendarCore::Calendar::Ptr &cal);
 
 /**
   Return, if drag&drop object can be decode to iCalendar.
 */
-Q_REQUIRED_RESULT KCALUTILS_EXPORT bool canDecode(const QMimeData *);
+[[nodiscard]] KCALUTILS_EXPORT bool canDecode(const QMimeData *);
 
 /**
   Decode drag&drop object to iCalendar component \a cal.
 */
-Q_REQUIRED_RESULT KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalendarCore::Calendar::Ptr &cal);
+[[nodiscard]] KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalendarCore::Calendar::Ptr &cal);
 }
 }
